==> hivemq-extension-sdk-4.3.0-sources.jar: com/hivemq/extension/sdk/api/interceptor/disconnect/DisconnectInboundInterceptor.java <==
/*
 * Copyright 2019 dc-square GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hivemq.extension.sdk.api.interceptor.disconnect;

import com.hivemq.extension.sdk.api.annotations.NotNull;
import com.hivemq.extension.sdk.api.interceptor.Interceptor;
import com.hivemq.extension.sdk.api.interceptor.disconnect.parameter.DisconnectInboundInput;
import com.hivemq.extension.sdk.api.interceptor.disconnect.parameter.DisconnectInboundOutput;

/**
 * Interface for the inbound DISCONNECT interception.
 * <p>
 * Interceptors are always called by the same Thread for all messages from the same client.
 * <p>
 * If the same instance is shared between multiple clients it can be called in different Threads and must therefore be
 * thread-safe.
 * </p>
 *
 * @author Robin Atherton
 */
@FunctionalInterface
public interface DisconnectInboundInterceptor extends Interceptor {

    /**
     * When a {@link DisconnectInboundInterceptor} is set through any extension, this method gets called for every
     * inbound DISCONNECT packet from any MQTT client.
     *
     * @param disconnectInboundInput  The {@link DisconnectInboundInput} parameter.
     * @param disconnectInboundOutput The {@link DisconnectInboundOutput} parameter.
     */
    void onInboundDisconnect(
            @NotNull DisconnectInboundInput disconnectInboundInput,
            @NotNull DisconnectInboundOutput disconnectInboundOutput);
}

==> hivemq-extension-sdk-4.17.0-sources.jar: com/hivemq/extension/sdk/api/interceptor/disconnect/DisconnectInboundInterceptor.java <==
/*
 * Copyright 2018-present HiveMQ GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hivemq.extension.sdk.api.interceptor.disconnect;

import com.hivemq.extension.sdk.api.annotations.NotNull;
import com.hivemq.extension.sdk.api.interceptor.Interceptor;
import com.hivemq.extension.sdk.api.interceptor.disconnect.parameter.DisconnectInboundInput;
import com.hivemq.extension.sdk.api.interceptor.disconnect.parameter.DisconnectInboundOutput;

/**
 * Interface for the inbound DISCONNECT interception.
 * <p>
 * Interceptors are always called by the same Thread for all messages from the same client.
 * <p>
 * If the same instance is shared between multiple clients it can be called in different Threads and must therefore be
 * thread-safe.
 *
 * @author Robin Atherton
 * @since 4.3.0, CE 2020.1
 */
@FunctionalInterface
public interface DisconnectInboundInterceptor extends Interceptor {

    /**
     * When a {@link DisconnectInboundInterceptor} is set through any extension, this method gets called for every
     * inbound DISCONNECT packet from any MQTT client.
     * <p>
     * When the extension is enabled after HiveMQ is already running, this method will also be called for future
     * DISCONNECT's of clients that are already connected.
     *
     * @param disconnectInboundInput  The {@link DisconnectInboundInput} parameter.
     * @param disconnectInboundOutput The {@link DisconnectInboundOutput} parameter.
     * @since 4.3.0, CE 2020.1
     */
    void onInboundDisconnect(
            @NotNull DisconnectInboundInput disconnectInboundInput,
            @NotNull DisconnectInboundOutput disconnectInboundOutput);
}
